*******************************************************************************
****  Stata-program (do-file) associated with the lectures on day three.   ****
****                  Erik Parner                                          ****
*******************************************************************************

* My data is in "D:\Teaching\BasicBiostat\Lectures\Day3"
cd "D:\Teaching\BasicBiostat\Lectures\Day3"

capture log close
log using day3.log, replace

**********************************************************************
* Exercise 2.3
**********************************************************************
use hp.dta,clear

* The data follows approximately a normal distribution. However there seems 
* a slightly long right tail for the passive.
dotplot day,over(group) name(p1,replace) center
graph box day,over(group) name(p2,replace)
graph combine  p1 p2 , name(pA,replace) col(1)
qnorm day if group==1, name(p2,replace)
qnorm day if group==2, name(p3,replace)
graph combine  p2 p3 , name(pB,replace) col(1) 
graph combine  pA pB, name(Figure1,replace) col(2)
graph drop p1 p2 p3 pA pB

* The unequal distribution matters to the validity of the prediction interval
* for the passive.
* r(c_1): the 2.5 percentile found by the command centile.
* r(c_2): the 97.5 percentile found by the command centile.
centile day if group==1, centile(2.5 97.5) meansd
sum day if day<r(c_1) & group==1
sum day if day>r(c_2) & group==1

centile day if group==2, centile(2.5 97.5) meansd
sum day if day<r(c_1) & group==2
sum day if day>r(c_2) & group==2


* Active have a longer heart period (ie lower heart rate)
* than the passive (the mean difference somewhere between 33 and 120ms)
* There are no problems due to variance homogenity
* The non-parametric test gives the same conclusion
sdtest day ,by(group)
ttest day ,by(group)
ranksum day,by(group)
graph drop _all

* On the log-scale.
gen logday=ln(day)
dotplot logday,over(group) name(p1,replace) center
graph box logday,over(group) name(p2,replace)
graph combine  p1 p2 , name(pA,replace) col(1)
qnorm logday if group==1, name(p2,replace)
qnorm logday if group==2, name(p3,replace)
graph combine  p2 p3 , name(pB,replace) col(1) 
graph combine  pA pB, name(Figure1,replace) col(2)
graph drop p1 p2 p3 pA pB
sdtest logday ,by(group)
ttest logday ,by(group)
disp exp(-.0926516) "  95% CI: (" exp(-.1446113) ";" exp(-.040692) ")"
graph drop _all


*******************************************************************************
* Continous data - two sample paried 
*******************************************************************************
use energy.dta, clear

*******************************************************************************
* Figure 3.1
*******************************************************************************
* The option -aspect(1)- makes the plot region square
twoway  ///
  (scatter post pre, msy(O))        /// First plot, marker symbol an open circle
  (function y=x, range(2000 10000)) /// Second plot, a "function" wiz a line
  , aspect(1) legend(off)           /// Square plot with no legend
   xtitle("Pre-menstrual intake") ytitle("Post-menstrual intake")
                   /* Legends for the X- and Y-axes */

* You could use "png" (Portable Networks Graphics) as format instead
* of "wmf" if you use Mac or Linux, since wmf is Windows-only. "eps"
* (Encapsulated PostScript) is the industry standard for publishing
* graphs in journals, and this can also specified in Stata:
graph export figure3_1.wmf, replace
graph export figure3_1.png, replace
graph export figure3_1.eps, replace

*******************************************************************************
* generating  the difference and averages for the plots
*******************************************************************************
generate dif=post-pre
generate ave=(post+pre)/2
label var dif "post-pre"
label var ave "(post+pre)/2"
sum dif

*******************************************************************************
* Figure  3.2
*******************************************************************************
scatter dif ave , msy(O) yline(0 -1320.455)
graph export figure3_2.wmf, replace


*******************************************************************************
* Figure  3.3
*******************************************************************************
histogram dif ,norm  name(p1, replace) start(-2000) width(200)
qnorm dif , name(p2, replace) msy(O)
graph combine  p1 p2
graph export figure3_3.wmf, replace
graph drop p1 p2

*******************************************************************************
* estimation, confidence interval, prediction intervals and t-test
*******************************************************************************
ttest pre=post

*******************************************************************************
* Figure 3.4. 
*******************************************************************************
centile dif, c(2.5 97.5) meansd

scatter dif ave, msy(O)  aspect(1)              ///  Ploting symbols and square plot
   yscale(range(-2500 0)) ylabel(-2500 (500) 0) ///  Scaling and labels for the y-axis
   yline(0 -1320 )                              ///  lines for zero and mean
   yline( -2039 -602 )                          ///  lines for  PI
   yline(-1567 -1074,lpa(dash) )                  /* lines for  CI           */
graph export figure3_4.wmf, replace

*******************************************************************************
* Figure 3.5
* This plot is a bit complicated as one has to restructure the data
* using the reshape command.
*******************************************************************************
use energy.dta, clear

keep id pre post
rename pre  energy1
rename post energy2
reshape long energy,i(id) j(time)
sort id time
scatter energy time, /// The fundamental plot command
    msy(O)              /// Marker symbol: open circle
    aspect(1)           /// Square plot region
    connect(L)          /// Only connect in ascending order wrt x-coordinate
    xscale(range(0.8 2.2)) /// Range of x-axis
    xlabel(1 " Pre" 2 "Post")  /// Text shown instead of numbers 1 and 2
    ytitle( "Energy intake") /// Legend for y-axis
    xtitle("") /* Legend for x-axis (none here) */
graph export figure3_5.wmf, replace


*******************************************************************************
* Albumin: use the data albumin.dta and repeated the above syntax. 
*******************************************************************************

*******************************************************************************
* T4 and T8 cells: use the data t4t8.dta and repeated the above syntax. 
*******************************************************************************


*******************************************************************************
* Agreement between two methods or measurements
*******************************************************************************
use pefrwright, clear

* Comparing Wright and Mini Wright.
generate dif=pefrW1-pefrMW1
generate avg=(pefrW1+pefrMW1)/2
label var dif "Wright 1 - Mini Wright 1"
label var avg "Average Wright 1, Mini Wright 1"
set scheme lean1
scatter dif avg, yline(0) name(p1,replace)
qnorm dif,  name(p2,replace)
graph combine p1 p2
* Limits of agreement.
centile dif , centile(2.5 97.5) meansd
drop dif avg

* Two measurement on Wright.
generate dif=pefrW1-pefrW2
generate avg=(pefrW1+pefrW2)/2
label var dif "Wright 1 - Wright 2"
label var avg "Average Wright 1 and Wright 2"
scatter dif avg, yline(0) name(p1,replace)
qnorm dif,  name(p2,replace)
graph combine p1 p2
drop dif

* By hand computation.
* Estimating sd of the difference under a mean=0 assumption.
generate squardif=(pefrW1-pefrW2)^2
sum squardif
* Sd of difference.
disp sqrt(r(mean))
disp 1.96*sqrt(r(mean))
* Standard variation within a person (measurement error).
disp sqrt(r(mean))/sqrt(2)

* Mixed-effects linear regression.
qnorm avg
* We reshape the data to have it on a long format.
keep subject pefrW1 pefrW2
reshape long pefrW, i(subject) j(mnumber)
mixed pefr || subject: , reml stddeviations
* Limits-of-agreement/Repeatabilty coefficient.
disp 1.96*sqrt(2)*15.30667 "  95% CI: (" 1.96*sqrt(2)*10.93706  ";" 1.96*sqrt(2)*21.42202 ")"


*******************************************************************************
* power calculation
*******************************************************************************
display (.6/0.6931)^2 *13
power onemean 0.6931 0, sd(0.6) power(.95) 
* or: power pairedmeans 0.6931 0, sddiff(0.6) power(.95) 
* In Stata 12: sampsi 0.6931 0, sd1(0.6) power(.95) onesample


*******************************************************************************
* Wilcoxon sign rank
*******************************************************************************
use T4T8.dta, clear
generate logT4=ln(T4)
generate logT8=ln(T8)
signrank logT4=logT8

log close

